package
Version:
v0.0.0-...-95b71d7
Opens a new window with list of versions in this module.
Published: Feb 21, 2018
License: Apache-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type MetricEnvelope struct {
Metric Metric `json:"metric"`
Meta map[string]string `json:"meta"`
CreationTime int64 `json:"creation_time"`
}
type Rollup struct {
Function string
GroupedDimensions []string
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.